"""Metadate for Masonite package."""
__title__ = "masonite"
__description__ = "The core for the Masonite framework"
__url__ = "https://github.com/MasoniteFramework/masonite"
__version__ = "2.3.24"
__author__ = "Joseph Mancuso"
__author_email__ = "joe@masoniteproject.com"
__licence__ = "MIT"
